<?php
/** @var App\Models\Note $note */
?>
@extends ('layouts.patient')

@section('inner-content')

    <div class="pt-2 pb-3 d-flex align-items-start">
        <h6 class="my-0 text-secondary d-flex align-items-start">
            <a href="/patients/view/{{ $patient->uid }}/notes" class="small text-decoration-none mr-3">
                <i class="fa fa-chevron-left"></i>
            </a>
            <div>
                <span class="text-dark font-weight-bold">{{$note->title}}
                    <span class="text-secondary font-weight-normal">{{ $note->is_cancelled ? '(CANCELLED)' : '' }}</span>
                </span>
            </div>
        </h6>
    </div>

    <div class="card mb-0 {{ $note->is_cancelled ? 'cancelled-item' : '' }}">
        <div class="card-header d-flex align-items-start px-3">
            <div class="pr-2">
                {{$note->title}}
                <div moe>
                    <a href="" show start><i class="fa fa-edit"></i></a>
                    <form url="/api/note/putTitle">
                        <input type="hidden" name="uid" value="{{$note->uid}}">
                        <div class="mb-2">
                            <input type="text" name="title" value="{{$note->title}}" class="form-control form-control-sm"
                                   placeholder="Title">
                        </div>
                        <div class="form-group mb-0">
                            <button class="btn btn-primary btn-sm" submit>Submit</button>
                            <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                        </div>
                    </form>
                </div>
            </div>
            <div class="px-2 border-left">
                <div class="d-flex">
                    <span class="mr-2">{{friendly_date_time($note->effective_dateest, false)}}</span>
                    <span moe class="ml-auto">
                    <a href="" show start><i class="fa fa-calendar"></i></a>
                    <form url="/api/note/putEffectiveDateEST">
                        <input type="hidden" name="uid" value="{{$note->uid}}">
                        <div class="mb-2">
                            <label for="" class="text-secondary text-sm">Effective date EST</label>
                            <input type="date" name="effectiveDateEST" value="{{$note->effective_dateest}}" class="form-control form-control-sm">
                        </div>
                        <div class="mb-0">
                            <button class="btn btn-primary btn-sm" submit>Submit</button>
                            <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                        </div>
                    </form>
                </span>
                </div>
                <div class="d-flex">
                    <span class="mr-2">{{friendly_time($note->effective_time)}}</span>
                    <span moe class="ml-auto">
                    <a href="" show start><i class="fa fa-clock"></i></a>
                    <form url="/api/note/putEffectiveTime">
                        <input type="hidden" name="uid" value="{{$note->uid}}">
                        <div class="mb-2">
                            <label for="" class="text-secondary text-sm">Effective time </label>
                            <input type="time" name="effectiveTime" value="{{ date("H:i", strtotime($note->effective_time)) }}" class="form-control form-control-sm">
                        </div>
                        <div class="mb-0">
                            <button class="btn btn-primary btn-sm" submit>Submit</button>
                            <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                        </div>
                    </form>
                </span>
                </div>
            </div>

            <div class="px-2 border-left">
                <div class="d-flex">
                    <span class="mr-2"><span class="text-secondary">HCP:</span> {{$note->hcpPro->name_display}}</span>
                    <div moe class="ml-auto">
                        <a href="" show start><i class="fa fa-edit"></i></a>
                        <form url="/api/note/putHcp">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <select name="hcpProUid" class="form-control form-control-sm">
                                    <option value="">-- Select HCP Pro --</option>
                                    @foreach ($pros as $iPro)
                                        <option value="{{$iPro->uid}}" {{ $iPro->id === $note->hcpPro->id ? 'selected' : '' }}>{{$iPro->name_display}}</option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </div>
                </div>
                <div class="d-flex">
                    <span class="mr-2"><span class="text-secondary">Ally:</span> {{$note->allyPro->name_display}}</span>
                    <div moe class="ml-auto">
                        <a href="" show start><i class="fa fa-edit"></i></a>
                        <form url="/api/note/putAlly">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <select name="allyProUid" class="form-control form-control-sm">
                                    <option value="">-- Select Ally Pro --</option>
                                    @foreach ($pros as $iPro)
                                        <option value="{{$iPro->uid}}" {{ $iPro->id === $note->allyPro->id ? 'selected' : '' }}>{{$iPro->name_display}}</option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
            <div class="ml-auto d-flex align-items-start">
                <div class="pr-2 border-right">
                    <div>
                        @if($note->is_signed_by_hcp)
                            <span class="text-secondary">
                        <i class="fa fa-check"></i>
                        HCP Signed
                    </span>
                        @else
                            <div moe
                                 class="{{ $note->hcp_pro_id !== $pro->id ? 'moe-disabled' : '' }}"
                                 title="{{ $note->hcp_pro_id !== $pro->id ? 'Only the note\'s HCP can sign' : '' }}">
                                <a class="" href="" show start>Sign as HCP</a>
                                <form url="/api/note/signAsHcp">
                                    <input type="hidden" name="uid" value="{{$note->uid}}">
                                    <p>Sign this note as HCP?</p>
                                    <div class="mb-0">
                                        <button class="btn btn-success btn-sm" submit>Sign</button>
                                        <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                    </div>
                                </form>
                            </div>
                        @endif
                    </div>
                    <div>
                        @if($note->is_signed_by_ally)
                            <span class="text-secondary">
                        <i class="fa fa-check"></i>
                        Ally Signed
                    </span>
                        @else
                            <div moe
                                 class="{{ $note->ally_pro_id !== $pro->id ? 'moe-disabled' : '' }}"
                                 title="{{ $note->ally_pro_id !== $pro->id ? 'Only the note\'s Ally can sign' : '' }}">
                                <a class="" href="" show start>Sign as Ally</a>
                                <form url="/api/note/signAsAlly">
                                    <input type="hidden" name="uid" value="{{$note->uid}}">
                                    <p>Sign this note as Ally?</p>
                                    <div class="mb-0">
                                        <button class="btn btn-success btn-sm" submit>Sign</button>
                                        <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                    </div>
                                </form>
                            </div>
                        @endif
                    </div>
                </div>
                <div class="pl-2">
                    <div class="d-flex justify-content-end">
                        <div moe relatve class="">
                            <a class="" href="" show start>Create Bill</a>
                            <form url="/api/bill/createForNote" right>
                                <input type="hidden" name="noteUid" value="{{$note->uid}}">
                                <div class="mb-2">
                                    <label for="" class="text-secondary text-sm">Effective Date</label>
                                    <input type="date" name="effectiveDate" class="form-control form-control-sm" required>
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="code" placeholder="Code" class="form-control form-control-sm" required>
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason1" placeholder="Reason 1" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason2" placeholder="Reason 2" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="serviceLocation" placeholder="Service Location" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="modifier" placeholder="Modifier" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <input type="number" name="numberOfUnits" placeholder="Number of Units" class="form-control form-control-sm">
                                </div>
                                <div class="">
                                    <button class="btn btn-primary btn-sm" submit>Submit</button>
                                    <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                    </div>
                    <div class="d-flex justify-content-end">
                        @if(!$note->is_cancelled)
                        <div moe relatve class="">
                            <a class="text-danger" href="" show start>Cancel Note</a>
                            <form url="/api/note/cancel" right>
                                <input type="hidden" name="uid" value="{{$note->uid}}">
                                <p class="small mb-2">Are you sure you want to cancel this note?</p>
                                <div class="mb-2">
                                    <textarea name="memo" id="" cols="30" rows="5" placeholder="Memo" class="memo-textarea form-control form-control-sm"></textarea>
                                </div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-danger mr-2" submit>Yes</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>No</button>
                                </div>
                            </form>
                        </div>
                        @else
                            <span class="text-secondary font-weight-bold">CANCELLED</span>
                        @endif
                    </div>
                </div>
            </div>
        </div>
        <div class="card-body p-3">
            <div>

                <div class="mb-2">
                    <div>
                        {!! $note->free_text_html !!}
                    </div>
                </div>

                @if($note->bills->count())
                    <div class="mt-2">
                        <table class="table table-sm tabe-striped mb-0">
                            <thead class="bg-light">
                            <tr>
                                <th class="border-bottom-0 w-25">Code</th>
                                <th class="border-bottom-0"></th>
                            </tr>
                            </thead>
                            <tbody>
                            @foreach ($note->bills as $bill)
                                <tr>
                                    <td class="{{ $bill->is_cancelled ? 'text-secondary' : '' }}">{{$bill->code}}</td>
                                    <td>
                                        <div class="d-flex align-items-center">
                                            @if(!$bill->is_cancelled)
                                                @if($bill->is_signed_by_hcp)
                                                    <span class="text-secondary">
                                                <i class="fa fa-check"></i>
                                                HCP Signed
                                            </span>
                                                @else
                                                    <div moe
                                                         class="{{ $bill->hcp_pro_id !== $pro->id ? 'moe-disabled' : '' }}"
                                                         title="{{ $bill->hcp_pro_id !== $pro->id ? 'Only the bill\'s HCP can sign' : '' }}">
                                                        <a class="" href="" show start>Sign as HCP</a>
                                                        <form url="/api/bill/signAsHcp">
                                                            <input type="hidden" name="uid" value="{{$bill->uid}}">
                                                            <p>Sign this bill as HCP?</p>
                                                            <div class="mb-0">
                                                                <button class="btn btn-success btn-sm" submit>Sign</button>
                                                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                                            </div>
                                                        </form>
                                                    </div>
                                                @endif
                                                <span class="mx-2 text-secondary">|</span>
                                            @endif
                                            @if($bill->is_cancelled)
                                                <span class="text-secondary">
                                            Cancelled
                                        </span>
                                            @else
                                                <div moe>
                                                    <a class="" href="" show start>Cancel</a>
                                                    <form url="/api/bill/markCancelled">
                                                        <input type="hidden" name="uid" value="{{$bill->uid}}">
                                                        <p>Cancel this bill?</p>
                                                        <div class="mb-0">
                                                            <button class="btn btn-danger btn-sm" submit>Yes</button>
                                                            <button class="btn btn-default border btn-sm" cancel>No</button>
                                                        </div>
                                                    </form>
                                                </div>
                                            @endif
                                        </div>
                                    </td>
                                </tr>
                            @endforeach
                            </tbody>
                        </table>
                    </div>
                @endif
            </div>
        </div>
    </div>
@endsection
